/*
 * @(#)RotateDialogBox.java	1.0 08/15/04
 *
 * McGill Univarsity
 */

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
 * A dialog box that allows the user to select the number of degrees by which an
 * image is to be rotated and initiate the actions needed to perform the rotation.
 *
 * <p>The number entered into the <i>Degrees (+ve CW, -ve CCW)</i> field controls
 * the number of degrees by which the image is to be rotated. A positive number
 * indicates a clockwise rotation and a negative numbe indicates a counter-clockwise
 * rotation.
 *
 * <p>The <i>Rotate</i> button initiates the actions needed to perform the rotation
 * by the entered angle and the <i>Done</i> button hides this dialog box without
 * performing the rotation.
 *
 * <p>The entered amount of rotation can be accessed by other objects through this
 * class' <code>getRotationAmount</code> method.
 *
 * @author Cory McKay
 */ 
public class RotateDialogBox
	extends JFrame
	implements ActionListener
{
	/* FIELDS ******************************************************************/

	
	// Window that instantiated this window
	private MainFrame		parent_window;
	
	// Containers to hold Swing elements
	private Container		content_pane;
	private JPanel			settings_panel;
	private JPanel			button_panel;
	
	// The amount of rotation
	private JTextArea		rotation_amount_text_area;

	// Buttons
	private JButton			done_button;
	private JButton			rotate_button;


	/* CONSTRUCTOR *************************************************************/


	/**
	 * Basic constructor. Configures the panel and sets fields to defaults.
	 *
 	 * @param	parent	Name of the <code>MainFrame</code> window that spawned this dialog box.
	 */
	public RotateDialogBox(MainFrame parent)
	{
		// Window that instantiated this window
		parent_window = parent;

		// Configure overall window settings
		setTitle("Rotation Settings");
		int horizontal_gap = 6; // horizontal space between GUI elements
		int vertical_gap = 11; // horizontal space between GUI elements
		content_pane = getContentPane();
		content_pane.setLayout(new BorderLayout(horizontal_gap, vertical_gap));
		settings_panel = new JPanel(new GridLayout(1, 2, horizontal_gap, vertical_gap));
		button_panel = new JPanel(new FlowLayout());

		// Configure the settings elements
		int number_columns = 4;
		rotation_amount_text_area = new JTextArea("0.0", 1, number_columns);

		// Instantiate and configure buttons
		done_button = new JButton("Done");
		done_button.addActionListener(this);
		button_panel.add(done_button);
		rotate_button = new JButton("Rotate");
		rotate_button.addActionListener(this);
		button_panel.add(rotate_button);

		// Add labels and previously created elements to panels and container
		settings_panel.add(new JLabel("Degrees (+ve CW, -ve CCW):"));
		settings_panel.add(rotation_amount_text_area);

		// Add elements to the dialog box
		content_pane.add(settings_panel, BorderLayout.CENTER);
		content_pane.add(button_panel, BorderLayout.SOUTH);

		// Cause program to react when the exit box is pressed
		addWindowListener(new WindowAdapter()
		{
			public void windowClosing (WindowEvent e) { done(); }
		});

		// Prepare GUI for display
		pack();
	}


	/* PUBLIC METHODS **********************************************************/

	
	/**
	 * Calls the appropriate methods when the buttons are pressed.
	 *
	 * @param	event		The event that is to be reacted to.
	 */
	public void actionPerformed(ActionEvent event)
	{
		// React to the done_button
		if (event.getSource().equals(done_button))
			done();

		// React to the rotate_button
		else if (event.getSource().equals(rotate_button))
			parent_window.rotate();
	}

	
	/**
	 * Returns the entered amount of rotation, in degrees (a positive value
	 * corresponds to a clockwise rotation and a negative value to a counterclockwise
	 * rotation.
	 */
	public double getRotationAmount()
	{
		return Double.parseDouble(rotation_amount_text_area.getText());
	}


	/* PRIVATE METHODS *********************************************************/


	/**
	 * Hides this dialog box.
	 */
	private void done()
	{
		this.hide();
	}
}